# References

If you use this library, please cite: [![DOI](https://zenodo.org/badge/364573913.svg)](https://zenodo.org/badge/latestdoi/364573913).

Please also consider citing: [rapids-single-cell-examples](https://zenodo.org/badge/latestdoi/265649968).

```{bibliography}
:cited:
```
